@@ -11,8 +11,8 @@
 #'   \code{data.frame} or \code{matrix}.
 #'   
 #' @param method One of the 21 dissimilarity coefficients available in the 
-#'   function: \code{"hellinger"}, \code{"chord"}, \code{"chisquare"}, 
-#'   \code{"profiles"}, \code{"percentdiff"}, \code{"ruzicka"}, 
+#'   function: \code{"hellinger"}, \code{"chord"}, \code{"log.chord"}, 
+#'   \code{"chisquare"}, \code{"profiles"}, \code{"percentdiff"}, \code{"ruzicka"}, 
 #'   \code{"divergence"}, \code{"canberra"}, \code{"whittaker"}, 
 #'   \code{"wishart"}, \code{"kulczynski"}, \code{"jaccard"}, \code{"sorensen"},
 #'   \code{"ochiai"}, \code{"ab.jaccard"}, \code{"ab.sorensen"}, 
@@ -43,23 +43,30 @@
 #'   sum of values in Y. The indices are computed by functions written in C for 
 #'   greater computation speed with large data matrices. \itemize{ \item Group 1
 #'   - D computed by transformation of Y followed by Euclidean distance 
-#'   \itemize{\item Hellinger D, D[ik] = 
-#'   sqrt(sum((sqrt(y[ij]/y[i+])-sqrt(y[kj]/y[k+]))^2)) \item chord D, D[ik] = 
-#'   sqrt(sum((y[ij]/sqrt(sum(y[ij]^2))-y[kj]/sqrt(sum(y[kj]^2)))^2)) \item 
-#'   chi-square D, D[ik] = sqrt(y[++] sum((1/j[+j])(y[ij]/y[i+]-y[kj]/y[k+])^2))
+#'   \itemize{
+#'   \item Hellinger D, D[ik] = 
+#'   sqrt(sum((sqrt(y[ij]/y[i+])-sqrt(y[kj]/y[k+]))^2)) 
+#'   \item chord D, D[ik] = 
+#'   sqrt(sum((y[ij]/sqrt(sum(y[ij]^2))-y[kj]/sqrt(sum(y[kj]^2)))^2)) 
+#'   \item log-chord D, D[ik] = chord D[ik] computed on log(y[ij]+1)-transformed 
+#'   data (Legendre and Borcard submitted)
+#'   \item chi-square D, D[ik] = 
+#'   sqrt(y[++] sum((1/j[+j])(y[ij]/y[i+]-y[kj]/y[k+])^2))
 #'   \item species profiles D, D[ik] = sqrt(sum((y[ij]/y[i+]-y[kj]/y[k+])^2)) }
 #'   
 #'   \item Group 2 - Other D functions appropriate for beta diversity studies 
-#'   where A = sum(min(y[ij],y[kj])), B = y[i+]-A, C = y[k+]-A \itemize{\item 
-#'   percentage difference D, D[ik] = (sum(abs(y[ij]-y[k,j])))/(y[i+]+y[k+]) or 
-#'   else, D[ik] = (B+C)/(2A+B+C) = \item Ružička D, D[ik] = 
-#'   1-(sum(min(y[ij],y[kj])/sum(max(y[ij],y[kj])) or else, D[ik] = 
-#'   (B+C)/(A+B+C) \item coeff. of divergence D, D[ik] = 
-#'   sqrt((1/pp)sum(((y[ij]-y(kj])/(y[ij]+y(kj]))^2)) \item Canberra metric D, 
-#'   D[ik] = (1/pp)sum(abs(y[ij]-y(kj])/(y[ij]+y(kj])) \item Whittaker D, D[ik] 
-#'   = 0.5*sum(abs(y[ij]/y[i+]-y(kj]/y[k+])) \item Wishart D, D[ik] = 
-#'   1-sum(y[ij]y[kj])/(sum(y[ij]^2)+sum(y[kj]^2)-sum(y[ij]y[kj])) \item 
-#'   Kulczynski D, D[ik] = 
+#'   where A = sum(min(y[ij],y[kj])), B = y[i+]-A, C = y[k+]-A 
+#'   \itemize{\item percentage difference D (aka Bray-Curtis), 
+#'   D[ik] = (sum(abs(y[ij]-y[k,j])))/(y[i+]+y[k+]) or else, D[ik] = (B+C)/(2A+B+C) 
+#'   \item Ružička D, D[ik] = 1-(sum(min(y[ij],y[kj])/sum(max(y[ij],y[kj])) 
+#'   or else, D[ik] = (B+C)/(A+B+C) 
+#'   \item coeff. of divergence D, D[ik] = 
+#'   sqrt((1/pp)sum(((y[ij]-y(kj])/(y[ij]+y(kj]))^2)) 
+#'   \item Canberra metric D, D[ik] = (1/pp)sum(abs(y[ij]-y(kj])/(y[ij]+y(kj]))
+#'   \item Whittaker D, D[ik] = 0.5*sum(abs(y[ij]/y[i+]-y(kj]/y[k+])) 
+#'   \item Wishart D, D[ik] = 
+#'   1-sum(y[ij]y[kj])/(sum(y[ij]^2)+sum(y[kj]^2)-sum(y[ij]y[kj])) 
+#'   \item Kulczynski D, D[ik] = 
 #'   1-0.5((sum(min(y[ij],y[kj])/y[i+]+sum(min(y[ij],y[kj])/y[k+])) }
 #'   
 #'   \item Group 3 - Classical indices for binary data; they are appropriate for
@@ -145,6 +152,9 @@
 #'   Abundance-based similarity indices and their estimation when there are 
 #'   unseen species in samples. Biometrics 62: 361–371.
 #'   
+#'   Legendre, P. and D. Borcard. (Submitted). Box-Cox-chord transformations for 
+#'   community composition data prior to beta diversity analysis.
+#'   
 #'   Legendre, P. and M. De Cáceres. 2013. Beta diversity as the variance of 
 #'   community data: dissimilarity coefficients and partitioning. Ecology 
 #'   Letters 16: 951-963.
@@ -177,6 +187,7 @@
 #' 
 #' 
 #' @export dist.ldc
+
 dist.ldc <-
     function(Y,
         method = "hellinger",
@@ -191,6 +202,7 @@ dist.ldc <-
                 c(
                     "hellinger",
                     "chord",
+                    "log.chord",
                     "chisquare",
                     "profiles",
                     "percentdiff",
@@ -214,6 +226,7 @@ dist.ldc <-
             )
         #
         Y <- as.matrix(Y)
+        if(sum( scale(Y, scale=FALSE)^2 )==0) stop("The data matrix has no variation")
         n <- nrow(Y)
         
         if ((n == 2) &
@@ -237,7 +250,7 @@ dist.ldc <-
                 YY = .Call("transform_mat", Y, "hellinger")
                 D = .Call("euclidean", YY)
                 if (!silent)
-                    cat("Info -- This coefficient is Euclidean***\n")
+                    cat("Info -- This coefficient is Euclidean\n")
             },
             chord = {
                 YY = .Call("transform_mat", Y, "chord")
@@ -245,6 +258,13 @@ dist.ldc <-
                 if (!silent)
                     cat("Info -- This coefficient is Euclidean\n")
             },
+            log.chord = {
+                Y = log1p(Y)
+                YY = .Call("transform_mat", Y, "chord")
+                D = .Call("euclidean", YY)
+                if (!silent)
+                    cat("Info -- This coefficient is Euclidean\n")
+            },
             chisquare = {
                 YY = .Call("transform_mat", Y, "chisquare")
                 D = .Call("euclidean", YY)
